# pyExoyOne

<p align="center">
  <a href="https://github.com/Djelibeybi/pyexoyone/actions/workflows/ci.yml?query=branch%3Amain">
    <img src="https://img.shields.io/github/actions/workflow/status/Djelibeybi/pyexoyone/ci.yml?branch=main&label=CI&logo=github&style=flat-square" alt="CI Status" >
  </a>
  <a href="https://codecov.io/gh/Djelibeybi/pyexoyone">
    <img src="https://img.shields.io/codecov/c/github/Djelibeybi/pyexoyone.svg?logo=codecov&logoColor=fff&style=flat-square" alt="Test coverage percentage">
  </a>
</p>
<p align="center">
  <a href="https://python-poetry.org/">
    <img src="https://img.shields.io/endpoint?url=https://python-poetry.org/badge/v0.json" alt="Poetry">
  </a>
  <a href="https://github.com/astral-sh/ruff">
    <img src="https://img.shields.io/endpoint?url=https://raw.githubusercontent.com/astral-sh/ruff/main/assets/badge/v2.json" alt="Ruff">
  </a>
  <a href="https://github.com/pre-commit/pre-commit">
    <img src="https://img.shields.io/badge/pre--commit-enabled-brightgreen?logo=pre-commit&logoColor=white&style=flat-square" alt="pre-commit">
  </a>
</p>
<p align="center">
  <a href="https://pypi.org/project/pyexoyone/">
    <img src="https://img.shields.io/pypi/v/pyexoyone.svg?logo=python&logoColor=fff&style=flat-square" alt="PyPI Version">
  </a>
  <img src="https://img.shields.io/pypi/pyversions/pyexoyone.svg?style=flat-square&logo=python&amp;logoColor=fff" alt="Supported Python versions">
  <img src="https://img.shields.io/pypi/l/pyexoyone.svg?style=flat-square" alt="License">
</p>

---

**Documentation**: <a href="https://djelibeybi.github.io/pyExoyOne" target="_blank">https://djelibeybi.github.io/pyExoyOne </a>

**Source Code**: <a href="https://github.com/Djelibeybi/pyexoyone" target="_blank">https://github.com/Djelibeybi/pyexoyone </a>

---

This library and command-line utility allow you to configure and control [Exoy&trade; ONE](https://exoylighting.com/) devices.

## Installation

Install this via pip (or your favourite package manager):

`pip install pyexoyone`

## Usage

The library provides the `exoyone` CLI tool that allows you to `get` and `set`
almost everything possible on the ExoyOne.

## Contributors ✨

Thanks goes to these wonderful people ([emoji key](https://allcontributors.org/docs/en/emoji-key)):

<!-- prettier-ignore-start -->
<!-- ALL-CONTRIBUTORS-LIST:START - Do not remove or modify this section -->
<!-- prettier-ignore-start -->
<!-- markdownlint-disable -->
<table>
  <tbody>
    <tr>
      <td align="center" valign="top" width="14.28%"><a href="https://omg.dje.li"><img src="https://avatars.githubusercontent.com/u/103232?v=4?s=80" width="80px;" alt="Avi Miller"/><br /><sub><b>Avi Miller</b></sub></a><br /><a href="https://github.com/Djelibeybi/pyExoyOne/commits?author=Djelibeybi" title="Code">💻</a> <a href="https://github.com/Djelibeybi/pyExoyOne/commits?author=Djelibeybi" title="Documentation">📖</a> <a href="#question-Djelibeybi" title="Answering Questions">💬</a> <a href="https://github.com/Djelibeybi/pyExoyOne/pulls?q=is%3Apr+reviewed-by%3ADjelibeybi" title="Reviewed Pull Requests">👀</a></td>
    </tr>
  </tbody>
</table>

<!-- markdownlint-restore -->
<!-- prettier-ignore-end -->

<!-- ALL-CONTRIBUTORS-LIST:END -->
<!-- prettier-ignore-end -->

This project follows the [all-contributors](https://github.com/all-contributors/all-contributors) specification. Contributions of any kind welcome!

## Credits

This package was created with
[Copier](https://copier.readthedocs.io/) and the
[browniebroke/pypackage-template](https://github.com/browniebroke/pypackage-template)
project template.
